<?php

	############################################################################
	#
	#	Meteotemplate
	# 	http://www.meteotemplate.com
	# 	Free website template for weather enthusiasts
	# 	Author: Jachym
	#           Brno, Czech Republic
	# 	First release: 2015
	#
	############################################################################
	#
	#	Influenza - U.S.
	#
	# 	A plugin showing influenza spread in the U.S.
	#
	############################################################################
	#	Version and change log
	#
	# 	v1.0 	2015-12-25	Initial release
	#
	############################################################################

	include("../../config.php");
	include($baseURL."css/design.php");
	include($baseURL."header.php");

	// get week numbers
	if(!is_dir("cache")){
		mkdir("cache");
	}

	if(file_exists("cache/fluData.txt")){
		if (time()-filemtime("cache/fluData.txt") > 60 * 60 * 24) {
			unlink("cache/fluData.txt");
		}
	}

	if(file_exists("cache/fluData.txt")){
		$rawData = file_get_contents("cache/fluData.txt");
	}
	else{
		$rawData = file_get_contents("https://www.cdc.gov/flu/weekly/flureport.xml");
		if($rawData==""){
			$rawData = curlMain("https://www.cdc.gov/flu/weekly/flureport.xml",5);
		}
		if($rawData!=""){
			file_put_contents("cache/fluData.txt",$rawData);
		}
	}

	$xml = simplexml_load_string($rawData);
	if(count($xml->timeperiod)>0){
		foreach($xml->timeperiod as $period){
			$week = (int)$period['number'];
			$title = (string)$period['subtitle'];
			$weeks[] = array($week,$title);
		}
	}
?>
<!DOCTYPE html>
<html>
	<head>
		<title><?php echo $pageName?></title>
		<?php metaHeader()?>
		<script src="//code.highcharts.com/highcharts.src.js"></script>
		<script src="//code.highcharts.com/maps/modules/map.src.js"></script>
		<script src="//code.highcharts.com/maps/modules/exporting.js"></script>
		<script src="//code.highcharts.com/mapdata/countries/us/us-all.js"></script>
		<style>

		</style>
	</head>
	<body>
		<div id="main_top">
			<?php bodyHeader();?>
			<?php include($baseURL."menu.php");?>
		</div>
		<div id="main" style="text-align:center">
			<h1>Influenza Summary</h1>
			<div style="width:98%;margin: 0 auto;text-align:center">
				<select class="button2" id="selectWeek">
					<?php
						for($i=0;$i<count($weeks);$i++){
					?>
							<option value="<?php echo $weeks[$i][0]?>">
								<?php echo $weeks[$i][1]?>
							</option>
					<?php
						}
					?>
				</select>
			</div>
			<table style="width:98%;margin:0 auto">
				<tr>
					<td style="width:80%">
						<div id="map" style="width:98;margin:0 auto;height:600px"></div>
					</td>
					<td style="text-align:left">
						<br />
						0 - No Report<br />
						1 - No Activity<br />
						2 - Sporadic<br />
						3 - Local Activity<br />
						4 - Regional<br />
						5 - Widespread<br />
					</td>
				</tr>
			</table>
			<br /><br />
			<div style="width:98%;margin: 0 auto;text-align:center;font-size:0.8em">
				<?php echo lang('data source','c')?>: Centers for Disease Control and Prevention, National Center for Immunization and Respiratory Diseases (NCIRD)
			</div>
			<br /><br />
		</div>
		<?php include($baseURL."footer.php");?>
	</body>
	<script>
		lastWeek = <?php echo $weeks[(count($weeks)-1)][0]?>;
		$("#selectWeek").val(lastWeek);
		$("#selectWeek").change(function(){
			switchWeek($(this).val());
		});
		$('#map').highcharts('Map', {
			chart: {
				backgroundColor: null,
			},
			title: {
				text: ''
			},
			mapNavigation: {
				enabled: true,
				buttonOptions: {
					verticalAlign: 'bottom'
				}
			},
			colorAxis: {
				maxColor: "#<?php echo $color_schemes[$design2]['900']?>",
				min: 0,
				max: 5,
				tickInterval: 1,
				minorTickInterval: 1,
			},
			plotOptions:{
				map:{
					mapData: Highcharts.maps['countries/us/us-all'],
					joinBy: 'hc-key',
				},
			},
			series: [
				{
					name: 'Influenza',
					data: [],
				}
			]
		});
		switchWeek(lastWeek);
		function switchWeek(week){
			$.ajax({
				url : "loadData.php?week="+week,
				dataType : 'json',
				success : function (json) {
					var currentMap = $('#map').highcharts();
					currentMap.series[0].update({
						data: json['mapData']
					});
					//currentMap.reflow();
				},
			});
		}
	</script>
</html>
